@@ -96,10 +96,11 @@ class Clock():
         self.drawing_area.set_size_request(size[0] + 18, size[1])
 
     def set_alarm_enabled(self, b):
-        self.alarm_enabled = b
-        if self.alarm_enabled and self.alarm_indicator_enabled :
+        if (not self.alarm_enabled) and b and self.alarm_indicator_enabled :
+            self.alarm_enabled = b
             self.resize_alarm_enabled()
         else :
+            self.alarm_enabled = False
             self.resize()
 
     def set_alarm_indicator_enabled(self, b):
