@@ -19,6 +19,7 @@ import cairo
 from datetime import datetime
 import gtk
 import math
+import pango
 
 import clock
 
@@ -52,29 +53,33 @@ class DecimalClock(clock.Clock):
         else :
             self.context.stroke()
 
-
         if self.twelve_hour_mode :
             self.context.set_font_size(20)
 
             if self.show_seconds :
-                self.context.move_to(180, 35)
+                self.context.move_to((self.char_width * 8), 35)
             else :
-                self.context.move_to(120, 35)
+                self.context.move_to((self.char_width * 5), 35)
             
             self.context.text_path(abrv)
             self.context.stroke()
 
     def resize(self):
+        ctx = self.drawing_area.create_pango_context()
+        fdesc = pango.FontDescription(self.font_name + " 45")  
+        metric = ctx.get_metrics(fdesc)
+        self.char_width = int(metric.get_approximate_digit_width() / pango.SCALE * 0.7)
+
         if self.twelve_hour_mode :
             if self.show_seconds :
-                self.drawing_area.set_size_request(212, 36)
+                self.drawing_area.set_size_request((self.char_width * 8) + 40, 36)
             else:
-                self.drawing_area.set_size_request(152, 36)
+                self.drawing_area.set_size_request((self.char_width * 5) + 40, 36)
         else :
             if self.show_seconds :
-                self.drawing_area.set_size_request(178, 36)
+                self.drawing_area.set_size_request(self.char_width * 8, 36)
             else:
-                self.drawing_area.set_size_request(118, 36)
+                self.drawing_area.set_size_request(self.char_width * 5, 36)
 
     def resize_alarm_enabled(self):
         if not self.twelve_hour_mode :
